@@ -12,7 +12,7 @@ module Parser where
 import Data.Char
 import Data.String.Utils (lstrip)
 import ID
-import Lexer
+import LexerV3
 import Blocks
 import qualified Control.Monad as Happy_Prelude
 import qualified Data.Bool as Happy_Prelude
@@ -132,7 +132,7 @@ happyReduce_7 = happyReduce 4# 2# happyReduction_7
 happyReduction_7 (_ `HappyStk`
         (HappyAbsSyn6  happy_var_3) `HappyStk`
         _ `HappyStk`
-        (HappyTerminal (TokenAction happy_var_1)) `HappyStk`
+        (HappyTerminal (TokenAction _ happy_var_1)) `HappyStk`
         happyRest)
          = HappyAbsSyn7
                  (happy_var_3 <> [toHeadline happy_var_1]
@@ -140,17 +140,17 @@ happyReduction_7 (_ `HappyStk`
 
 happyReduce_8 = happyReduce 5# 2# happyReduction_8
 happyReduction_8 (_ `HappyStk`
-        (HappyTerminal (TokenSoloIdentifier happy_var_4)) `HappyStk`
+        (HappyTerminal (TokenSoloIdentifier _ happy_var_4)) `HappyStk`
         (HappyAbsSyn6  happy_var_3) `HappyStk`
         _ `HappyStk`
-        (HappyTerminal (TokenAction happy_var_1)) `HappyStk`
+        (HappyTerminal (TokenAction _ happy_var_1)) `HappyStk`
         happyRest)
          = HappyAbsSyn7
                  (toAddress happy_var_4 : happy_var_3 <> [toHeadline happy_var_1]
         ) `HappyStk` happyRest
 
 happyReduce_9 = happySpecReduce_1  3# happyReduction_9
-happyReduction_9 (HappyTerminal (TokenAction happy_var_1))
+happyReduction_9 (HappyTerminal (TokenAction _ happy_var_1))
          =  HappyAbsSyn8
                  (toAction happy_var_1
         )
@@ -163,7 +163,7 @@ happyReduction_10 (_ `HappyStk`
         _ `HappyStk`
         (HappyAbsSyn6  happy_var_3) `HappyStk`
         _ `HappyStk`
-        (HappyTerminal (TokenAction happy_var_1)) `HappyStk`
+        (HappyTerminal (TokenAction _ happy_var_1)) `HappyStk`
         happyRest)
          = HappyAbsSyn8
                  (toFork happy_var_1 happy_var_3 happy_var_6 Nothing
@@ -171,13 +171,13 @@ happyReduction_10 (_ `HappyStk`
 
 happyReduce_11 = happyReduce 8# 3# happyReduction_11
 happyReduction_11 (_ `HappyStk`
-        (HappyTerminal (TokenSoloIdentifier happy_var_7)) `HappyStk`
+        (HappyTerminal (TokenSoloIdentifier _ happy_var_7)) `HappyStk`
         (HappyAbsSyn6  happy_var_6) `HappyStk`
         _ `HappyStk`
         _ `HappyStk`
         (HappyAbsSyn6  happy_var_3) `HappyStk`
         _ `HappyStk`
-        (HappyTerminal (TokenAction happy_var_1)) `HappyStk`
+        (HappyTerminal (TokenAction _ happy_var_1)) `HappyStk`
         happyRest)
          = HappyAbsSyn8
                  (toFork happy_var_1 happy_var_3 happy_var_6 (Just (ID happy_var_7))
@@ -185,13 +185,13 @@ happyReduction_11 (_ `HappyStk`
 
 happyReduce_12 = happyReduce 8# 3# happyReduction_12
 happyReduction_12 (_ `HappyStk`
-        (HappyTerminal (TokenSoloIdentifier happy_var_7)) `HappyStk`
+        (HappyTerminal (TokenSoloIdentifier _ happy_var_7)) `HappyStk`
         (HappyAbsSyn6  happy_var_6) `HappyStk`
         _ `HappyStk`
         _ `HappyStk`
         (HappyAbsSyn6  happy_var_3) `HappyStk`
         _ `HappyStk`
-        (HappyTerminal (TokenAction happy_var_1)) `HappyStk`
+        (HappyTerminal (TokenAction _ happy_var_1)) `HappyStk`
         happyRest)
          = HappyAbsSyn8
                  (toFork happy_var_1 happy_var_3 happy_var_6 (Just (ID happy_var_7))
@@ -204,17 +204,17 @@ happyReduction_13 (_ `HappyStk`
         _ `HappyStk`
         (HappyAbsSyn6  happy_var_3) `HappyStk`
         _ `HappyStk`
-        (HappyTerminal (TokenAction happy_var_1)) `HappyStk`
+        (HappyTerminal (TokenAction _ happy_var_1)) `HappyStk`
         happyRest)
          = HappyAbsSyn8
                  (toFork happy_var_1 happy_var_3 happy_var_6 Nothing
         ) `HappyStk` happyRest
 
 happyTerminalToTok term = case term of {
-        TokenAction happy_dollar_dollar -> 2#;
-        TokenSoloIdentifier happy_dollar_dollar -> 3#;
-        TokenOCB -> 4#;
-        TokenCCB -> 5#;
+        TokenAction _ happy_dollar_dollar -> 2#;
+        TokenSoloIdentifier _ happy_dollar_dollar -> 3#;
+        TokenOCB _ -> 4#;
+        TokenCCB _ -> 5#;
         _ -> -1#;
         }
 {-# NOINLINE happyTerminalToTok #-}
@@ -263,7 +263,9 @@ toContent t =
   in  take (length idFreeContent' - 1) idFreeContent'
 
 toAction :: String -> Block
-toAction t = Action (toId t) (toContent t)
+toAction t =
+    Action Nothing (show t)
+    -- Action (toId t) (toContent t)
 
 toFork :: String -> [Block] -> [Block] -> Maybe ID -> Block
 toFork t l r rId = Fork (toId t) (toContent t) l r rId
